%global debug_package %{nil}
#
# spec file for package shadowsocks-rust
#

Name:           shadowsocks-rust
Version:        1.23.0
Release:        1%{?dist}
Summary:        A Rust port of shadowsocks
License:        MIT
Group:          Productivity/Networking/Web/Proxy
URL:            https://github.com/shadowsocks/shadowsocks-rust
Packager:       Teddysun <i@teddysun.com>
Source0:        https://github.com/shadowsocks/shadowsocks-rust/archive/refs/tags/v%{version}.tar.gz#/shadowsocks-rust-%{version}.tar.gz
Source1:        %{name}-config.json
Source2:        %{name}-client.service
Source3:        %{name}-server.service
Source4:        %{name}-client@.service
Source5:        %{name}-server@.service
Conflicts:      python-shadowsocks python3-shadowsocks
Requires:       libcap openssl
BuildRequires:  openssl-devel gcc make
BuildRequires:  clang-devel

%if 0%{?fedora} >= 15 || 0%{?rhel} >=7
%global use_systemd 1
%else
%global use_systemd 0
%endif

%if 0%{?rhel} && 0%{?rhel} < 8
BuildRequires:  systemd
%else
BuildRequires:  systemd-rpm-macros
%endif
%{?systemd_requires}

%description
shadowsocks-rust is a rust port of lightweight secured scoks5 proxy.

%prep
%setup -q -n %{name}-%{version}

%build
SODIUM_BUILD_STATIC=yes
cargo build --release --features "full-extra"

%install
make install TARGET=release PREFIX=/usr/bin DESTDIR=%{buildroot}
%{__install} -d %{buildroot}%{_sysconfdir}/shadowsocks/
%{__install} -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/shadowsocks/
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 644 %{SOURCE2} %{buildroot}%{_unitdir}
%{__install} -m 644 %{SOURCE3} %{buildroot}%{_unitdir}
%{__install} -m 644 %{SOURCE4} %{buildroot}%{_unitdir}
%{__install} -m 644 %{SOURCE5} %{buildroot}%{_unitdir}

%post
%systemd_post %{name}-server.service
setcap cap_net_bind_service+ep %{_bindir}/sslocal \
       cap_net_bind_service+ep %{_bindir}/ssserver \
       cap_net_bind_service+ep %{_bindir}/ssservice

%preun
%systemd_preun %{name}-server.service
%systemd_preun %{name}-client.service
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    systemctl stop %{name}-server@'*'.service  > /dev/null 2>&1 || :
    systemctl stop %{name}-client@'*'.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-server@.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-client@.service  > /dev/null 2>&1 || :
fi

%postun
%systemd_postun_with_restart %{name}-server.service
%systemd_postun_with_restart %{name}-client.service
%systemd_postun_with_restart %{name}-server@'*'.service
%systemd_postun_with_restart %{name}-client@'*'.service

%files
%defattr(-,root,root)
%doc README.md
%dir %{_sysconfdir}/shadowsocks
%config(noreplace) %{_sysconfdir}/shadowsocks/%{name}-config.json
%license LICENSE
%{_bindir}/*
%{_unitdir}/%{name}-*.service

%changelog
* Thu Mar 20 2025 Teddysun <i@teddysun.com> - 1.23.0-1
- Update version to 1.23.0

* Fri Jan 03 2025 Teddysun <i@teddysun.com> - 1.22.0-1
- Update version to 1.22.0
- shadowsocks-rust binary crate default feature set to "full-extra" (full features with extra)

* Fri Oct 25 2024 Teddysun <i@teddysun.com> - 1.21.2-1
- Update version to 1.21.2

* Mon Sep 23 2024 Teddysun <i@teddysun.com> - 1.21.0-1
- Update version to 1.21.0

* Fri Aug 16 2024 Teddysun <i@teddysun.com> - 1.20.4-1
- Update version to 1.20.4

* Sun Aug 04 2024 Teddysun <i@teddysun.com> - 1.20.3-1
- Update version to 1.20.3

* Thu Jul 11 2024 Teddysun <i@teddysun.com> - 1.20.2-1
- Update version to 1.20.2

* Thu Jun 20 2024 Teddysun <i@teddysun.com> - 1.20.1-1
- Update version to 1.20.1

* Sat Jun 15 2024 Teddysun <i@teddysun.com> - 1.20.0-1
- Update version to 1.20.0

* Thu Jun 13 2024 Teddysun <i@teddysun.com> - 1.19.4-1
- Update version to 1.19.4

* Tue Jun 11 2024 Teddysun <i@teddysun.com> - 1.19.3-1
- Update version to 1.19.3

* Sat Jun 01 2024 Teddysun <i@teddysun.com> - 1.19.2-1
- Update version to 1.19.2

* Sun May 26 2024 Teddysun <i@teddysun.com> - 1.19.0-1
- Update version to 1.19.0

* Sat May 11 2024 Teddysun <i@teddysun.com> - 1.18.4-1
- Update version to 1.18.4

* Mon Apr 22 2024 Teddysun <i@teddysun.com> - 1.18.3-1
- Update version to 1.18.3

* Thu Mar 14 2024 Teddysun <i@teddysun.com> - 1.18.2-1
- Update version to 1.18.2

* Mon Feb 19 2024 Teddysun <i@teddysun.com> - 1.18.1-1
- Update version to 1.18.1

* Fri Feb 09 2024 Teddysun <i@teddysun.com> - 1.18.0-1
- Update version to 1.18.0

* Fri Feb 02 2024 Teddysun <i@teddysun.com> - 1.17.2-1
- Update version to 1.17.2

* Mon Jan 15 2024 Teddysun <i@teddysun.com> - 1.17.1-2
- Enabled Optional Feature aead-cipher-2022-extra

* Mon Nov 27 2023 Teddysun <i@teddysun.com> - 1.17.1-1
- Update version to 1.17.1

* Sun Oct 15 2023 Teddysun <i@teddysun.com> - 1.17.0-1
- Update version to 1.17.0

* Sat Sep 23 2023 Teddysun <i@teddysun.com> - 1.16.2-1
- Update version to 1.16.2

* Fri Sep 01 2023 Teddysun <i@teddysun.com> - 1.16.1-1
- Update version to 1.16.1

* Sun Aug 27 2023 Teddysun <i@teddysun.com> - 1.16.0-1
- Update version to 1.16.0

* Fri Jul 07 2023 Teddysun <i@teddysun.com> - 1.15.4-1
- Update version to 1.15.4

* Mon Mar 13 2023 Teddysun <i@teddysun.com> - 1.15.3-1
- Update version to 1.15.3

* Sat Dec 24 2022 Teddysun <i@teddysun.com> - 1.15.2-1
- Update version to 1.15.2

* Sat Dec 17 2022 Teddysun <i@teddysun.com> - 1.15.1-1
- Update version to 1.15.1

* Sat Dec 17 2022 Teddysun <i@teddysun.com> - 1.15.0-1
- Update version to 1.15.0

* Mon Oct 24 2022 Teddysun <i@teddysun.com> - 1.15.0.alpha.9-1
- Update version to 1.15.0-alpha.9

* Sat Jun 18 2022 Teddysun <i@teddysun.com> - 1.14.3-1
- Update version to 1.14.3
